#ifndef FNMATCH_COMPAT_H
#define FNMATCH_COMPAT_H
/*
 * Squashfs
 *
 * Copyright (c) 2015, 2024
 * Phillip Lougher <phillip@squashfs.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * fnmatch_compat.h
 */

#include <fnmatch.h>

#ifndef FNM_EXTMATCH
#define FNM_EXTMATCH	0
#endif

#endif
